/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataIntegrationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/data_integration#id DataIntegration#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/data_integration#name DataIntegration#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/data_integration#status DataIntegration#status}
    */
    readonly status?: string;
    /**
    * s3 block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/data_integration#s3 DataIntegration#s3}
    */
    readonly s3?: DataIntegrationS3;
}
export interface DataIntegrationS3 {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/data_integration#bucket_name DataIntegration#bucket_name}
    */
    readonly bucketName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/data_integration#subdir DataIntegration#subdir}
    */
    readonly subdir?: string;
}
export declare function dataIntegrationS3ToTerraform(struct?: DataIntegrationS3OutputReference | DataIntegrationS3): any;
export declare function dataIntegrationS3ToHclTerraform(struct?: DataIntegrationS3OutputReference | DataIntegrationS3): any;
export declare class DataIntegrationS3OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataIntegrationS3 | undefined;
    set internalValue(value: DataIntegrationS3 | undefined);
    private _bucketName?;
    get bucketName(): string;
    set bucketName(value: string);
    get bucketNameInput(): string | undefined;
    private _subdir?;
    get subdir(): string;
    set subdir(value: string);
    resetSubdir(): void;
    get subdirInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/data_integration spotinst_data_integration}
*/
export declare class DataIntegration extends cdktf.TerraformResource {
    static readonly tfResourceType = "spotinst_data_integration";
    /**
    * Generates CDKTF code for importing a DataIntegration resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataIntegration to import
    * @param importFromId The id of the existing DataIntegration that should be imported. Refer to the {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/data_integration#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataIntegration to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/data_integration spotinst_data_integration} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataIntegrationConfig
    */
    constructor(scope: Construct, id: string, config: DataIntegrationConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _status?;
    get status(): string;
    set status(value: string);
    resetStatus(): void;
    get statusInput(): string | undefined;
    private _s3;
    get s3(): DataIntegrationS3OutputReference;
    putS3(value: DataIntegrationS3): void;
    resetS3(): void;
    get s3Input(): DataIntegrationS3 | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
