/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface HealthCheckConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check#id HealthCheck#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check#name HealthCheck#name}
    */
    readonly name?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check#proxy_address HealthCheck#proxy_address}
    */
    readonly proxyAddress: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check#proxy_port HealthCheck#proxy_port}
    */
    readonly proxyPort?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check#resource_id HealthCheck#resource_id}
    */
    readonly resourceId: string;
    /**
    * check block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check#check HealthCheck#check}
    */
    readonly check?: HealthCheckCheck;
}
export interface HealthCheckCheck {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check#end_point HealthCheck#end_point}
    */
    readonly endPoint?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check#endpoint HealthCheck#endpoint}
    */
    readonly endpoint?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check#healthy HealthCheck#healthy}
    */
    readonly healthy: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check#interval HealthCheck#interval}
    */
    readonly interval: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check#port HealthCheck#port}
    */
    readonly port: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check#protocol HealthCheck#protocol}
    */
    readonly protocol: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check#time_out HealthCheck#time_out}
    */
    readonly timeOut?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check#timeout HealthCheck#timeout}
    */
    readonly timeout?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check#unhealthy HealthCheck#unhealthy}
    */
    readonly unhealthy: number;
}
export declare function healthCheckCheckToTerraform(struct?: HealthCheckCheckOutputReference | HealthCheckCheck): any;
export declare function healthCheckCheckToHclTerraform(struct?: HealthCheckCheckOutputReference | HealthCheckCheck): any;
export declare class HealthCheckCheckOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HealthCheckCheck | undefined;
    set internalValue(value: HealthCheckCheck | undefined);
    private _endPoint?;
    get endPoint(): string;
    set endPoint(value: string);
    resetEndPoint(): void;
    get endPointInput(): string | undefined;
    private _endpoint?;
    get endpoint(): string;
    set endpoint(value: string);
    resetEndpoint(): void;
    get endpointInput(): string | undefined;
    private _healthy?;
    get healthy(): number;
    set healthy(value: number);
    get healthyInput(): number | undefined;
    private _interval?;
    get interval(): number;
    set interval(value: number);
    get intervalInput(): number | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    get portInput(): number | undefined;
    private _protocol?;
    get protocol(): string;
    set protocol(value: string);
    get protocolInput(): string | undefined;
    private _timeOut?;
    get timeOut(): number;
    set timeOut(value: number);
    resetTimeOut(): void;
    get timeOutInput(): number | undefined;
    private _timeout?;
    get timeout(): number;
    set timeout(value: number);
    resetTimeout(): void;
    get timeoutInput(): number | undefined;
    private _unhealthy?;
    get unhealthy(): number;
    set unhealthy(value: number);
    get unhealthyInput(): number | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check spotinst_health_check}
*/
export declare class HealthCheck extends cdktf.TerraformResource {
    static readonly tfResourceType = "spotinst_health_check";
    /**
    * Generates CDKTF code for importing a HealthCheck resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the HealthCheck to import
    * @param importFromId The id of the existing HealthCheck that should be imported. Refer to the {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the HealthCheck to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs/resources/health_check spotinst_health_check} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options HealthCheckConfig
    */
    constructor(scope: Construct, id: string, config: HealthCheckConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _proxyAddress?;
    get proxyAddress(): string;
    set proxyAddress(value: string);
    get proxyAddressInput(): string | undefined;
    private _proxyPort?;
    get proxyPort(): number;
    set proxyPort(value: number);
    resetProxyPort(): void;
    get proxyPortInput(): number | undefined;
    private _resourceId?;
    get resourceId(): string;
    set resourceId(value: string);
    get resourceIdInput(): string | undefined;
    private _check;
    get check(): HealthCheckCheckOutputReference;
    putCheck(value: HealthCheckCheck): void;
    resetCheck(): void;
    get checkInput(): HealthCheckCheck | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
