/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SpotinstProviderConfig {
    /**
    * Spotinst Account ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs#account SpotinstProvider#account}
    */
    readonly account?: string;
    /**
    * Enable or disable the Spotinst provider
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs#enabled SpotinstProvider#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Spotinst SDK Feature Flags
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs#feature_flags SpotinstProvider#feature_flags}
    */
    readonly featureFlags?: string;
    /**
    * Spotinst Personal API Access Token
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs#token SpotinstProvider#token}
    */
    readonly token?: string;
    /**
    * Alias name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs#alias SpotinstProvider#alias}
    */
    readonly alias?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs spotinst}
*/
export declare class SpotinstProvider extends cdktf.TerraformProvider {
    static readonly tfResourceType = "spotinst";
    /**
    * Generates CDKTF code for importing a SpotinstProvider resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SpotinstProvider to import
    * @param importFromId The id of the existing SpotinstProvider that should be imported. Refer to the {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SpotinstProvider to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/spotinst/spotinst/1.216.1/docs spotinst} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SpotinstProviderConfig = {}
    */
    constructor(scope: Construct, id: string, config?: SpotinstProviderConfig);
    private _account?;
    get account(): string | undefined;
    set account(value: string | undefined);
    resetAccount(): void;
    get accountInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable | undefined;
    set enabled(value: boolean | cdktf.IResolvable | undefined);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _featureFlags?;
    get featureFlags(): string | undefined;
    set featureFlags(value: string | undefined);
    resetFeatureFlags(): void;
    get featureFlagsInput(): string | undefined;
    private _token?;
    get token(): string | undefined;
    set token(value: string | undefined);
    resetToken(): void;
    get tokenInput(): string | undefined;
    private _alias?;
    get alias(): string | undefined;
    set alias(value: string | undefined);
    resetAlias(): void;
    get aliasInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
